@@ -18,20 +18,26 @@ class Launch:
     @staticmethod
     def launch_grafis():
         se_ret = shell.ShellExecuteEx(fMask=0x140, lpFile=r"P:\GRAFIS\Grafis.exe", nShow=1)
-        print('Before')
-        sleep(5)
-        print('After')
-        Ui_tools.click((100, 100))
 
     # 1b
     @staticmethod
     def close_new_version_modal():
+        while True:
+            position = Ui_tools.getPosition(resource_path('\static\\1a.png'))
+            if position is not None:
+                break
+            sleep(0.01)
+
+        Ui_tools.click((100, 100))
         Ui_tools.hot_key('Esc')
 
     # 1c
     @staticmethod
     def close_temporary_files_modal():
-        position = Ui_tools.getPosition(resource_path('\static\\1b.png'))
+        while True:
+            position = Ui_tools.getPosition(resource_path('\static\\1b.png'))
+            if position is not None:
+                break
+            sleep(0.01)
 
-        if position is not None:
-            Ui_tools.hot_key('Esc')
+        Ui_tools.hot_key('Esc')
